@@ -1,4 +1,3 @@
-# coding:utf-8
 import itertools
 import logging
 import random
@@ -15,33 +14,33 @@ from tests.common import _save_target
 
 
 def test_on_predicate(monkeypatch):
-    monkeypatch.setattr('time.sleep', lambda x: None)
+    monkeypatch.setattr("time.sleep", lambda x: None)
 
     @backoff.on_predicate(backoff.expo)
     def return_true(log, n):
-        val = (len(log) == n - 1)
+        val = len(log) == n - 1
         log.append(val)
         return val
 
     log = []
     ret = return_true(log, 3)
     assert ret is True
-    assert 3 == len(log)
+    assert len(log) == 3
 
 
 def test_on_predicate_max_tries(monkeypatch):
-    monkeypatch.setattr('time.sleep', lambda x: None)
+    monkeypatch.setattr("time.sleep", lambda x: None)
 
     @backoff.on_predicate(backoff.expo, jitter=None, max_tries=3)
     def return_true(log, n):
-        val = (len(log) == n)
+        val = len(log) == n
         log.append(val)
         return val
 
     log = []
     ret = return_true(log, 10)
     assert ret is False
-    assert 3 == len(log)
+    assert len(log) == 3
 
 
 def test_on_predicate_max_time(monkeypatch):
@@ -55,17 +54,16 @@ def test_on_predicate_max_time(monkeypatch):
     def monotonic():
         return nows.pop()
 
-    monkeypatch.setattr('time.sleep', lambda x: None)
-    monkeypatch.setattr('time.monotonic', monotonic)
+    monkeypatch.setattr("time.sleep", lambda x: None)
+    monkeypatch.setattr("time.monotonic", monotonic)
 
     def giveup(details):
-        assert details['tries'] == 3
-        assert details['elapsed'] == 10.000005
+        assert details["tries"] == 3
+        assert details["elapsed"] == 10.000005
 
-    @backoff.on_predicate(backoff.expo, jitter=None, max_time=10,
-                          on_giveup=giveup)
+    @backoff.on_predicate(backoff.expo, jitter=None, max_time=10, on_giveup=giveup)
     def return_true(log, n):
-        val = (len(log) == n)
+        val = len(log) == n
         log.append(val)
         return val
 
@@ -86,20 +84,21 @@ def test_on_predicate_max_time_callable(monkeypatch):
     def monotonic():
         return nows.pop()
 
-    monkeypatch.setattr('time.sleep', lambda x: None)
-    monkeypatch.setattr('time.monotonic', monotonic)
+    monkeypatch.setattr("time.sleep", lambda x: None)
+    monkeypatch.setattr("time.monotonic", monotonic)
 
     def giveup(details):
-        assert details['tries'] == 3
-        assert details['elapsed'] == 10.000005
+        assert details["tries"] == 3
+        assert details["elapsed"] == 10.000005
 
     def lookup_max_time():
         return 10
 
-    @backoff.on_predicate(backoff.expo, jitter=None, max_time=lookup_max_time,
-                          on_giveup=giveup)
+    @backoff.on_predicate(
+        backoff.expo, jitter=None, max_time=lookup_max_time, on_giveup=giveup
+    )
     def return_true(log, n):
-        val = (len(log) == n)
+        val = len(log) == n
         log.append(val)
         return val
 
@@ -110,7 +109,7 @@ def test_on_predicate_max_time_callable(monkeypatch):
 
 
 def test_on_exception(monkeypatch):
-    monkeypatch.setattr('time.sleep', lambda x: None)
+    monkeypatch.setattr("time.sleep", lambda x: None)
 
     @backoff.on_exception(backoff.expo, KeyError)
     def keyerror_then_true(log, n):
@@ -122,11 +121,11 @@ def test_on_exception(monkeypatch):
 
     log = []
     assert keyerror_then_true(log, 3) is True
-    assert 3 == len(log)
+    assert len(log) == 3
 
 
 def test_on_exception_tuple(monkeypatch):
-    monkeypatch.setattr('time.sleep', lambda x: None)
+    monkeypatch.setattr("time.sleep", lambda x: None)
 
     @backoff.on_exception(backoff.expo, (KeyError, ValueError))
     def keyerror_valueerror_then_true(log):
@@ -141,13 +140,13 @@ def test_on_exception_tuple(monkeypatch):
 
     log = []
     assert keyerror_valueerror_then_true(log) is True
-    assert 2 == len(log)
+    assert len(log) == 2
     assert isinstance(log[0], KeyError)
     assert isinstance(log[1], ValueError)
 
 
 def test_on_exception_max_tries(monkeypatch):
-    monkeypatch.setattr('time.sleep', lambda x: None)
+    monkeypatch.setattr("time.sleep", lambda x: None)
 
     @backoff.on_exception(backoff.expo, KeyError, jitter=None, max_tries=3)
     def keyerror_then_true(log, n, foo=None):
@@ -161,14 +160,13 @@ def test_on_exception_max_tries(monkeypatch):
     with pytest.raises(KeyError):
         keyerror_then_true(log, 10, foo="bar")
 
-    assert 3 == len(log)
+    assert len(log) == 3
 
 
 def test_on_exception_max_tries_callable(monkeypatch):
-    monkeypatch.setattr('time.sleep', lambda x: None)
+    monkeypatch.setattr("time.sleep", lambda x: None)
 
-    @backoff.on_exception(backoff.expo, KeyError, jitter=None,
-                          max_tries=lambda: 3)
+    @backoff.on_exception(backoff.expo, KeyError, jitter=None, max_tries=lambda: 3)
     def keyerror_then_true(log, n, foo=None):
         if len(log) == n:
             return True
@@ -180,11 +178,11 @@ def test_on_exception_max_tries_callable(monkeypatch):
     with pytest.raises(KeyError):
         keyerror_then_true(log, 10, foo="bar")
 
-    assert 3 == len(log)
+    assert len(log) == 3
 
 
 def test_on_exception_constant_iterable(monkeypatch):
-    monkeypatch.setattr('time.sleep', lambda x: None)
+    monkeypatch.setattr("time.sleep", lambda x: None)
 
     backoffs = []
     giveups = []
@@ -211,7 +209,6 @@ def test_on_exception_constant_iterable(monkeypatch):
 
         successes.append(details)
 
-
     @backoff.on_exception(
         backoff.constant,
         KeyError,
@@ -221,7 +218,7 @@ def test_on_exception_constant_iterable(monkeypatch):
         on_success=on_success,
     )
     def endless_exceptions():
-        raise KeyError('foo')
+        raise KeyError("foo")
 
     with pytest.raises(KeyError):
         endless_exceptions()
@@ -232,17 +229,19 @@ def test_on_exception_constant_iterable(monkeypatch):
 
 
 def test_on_exception_success_random_jitter(monkeypatch):
-    monkeypatch.setattr('time.sleep', lambda x: None)
+    monkeypatch.setattr("time.sleep", lambda x: None)
 
     backoffs, giveups, successes = [], [], []
 
-    @backoff.on_exception(backoff.expo,
-                          Exception,
-                          on_success=successes.append,
-                          on_backoff=backoffs.append,
-                          on_giveup=giveups.append,
-                          jitter=backoff.random_jitter,
-                          factor=0.5)
+    @backoff.on_exception(
+        backoff.expo,
+        Exception,
+        on_success=successes.append,
+        on_backoff=backoffs.append,
+        on_giveup=giveups.append,
+        jitter=backoff.random_jitter,
+        factor=0.5,
+    )
     @_save_target
     def succeeder(*args, **kwargs):
         # succeed after we've backed off twice
@@ -258,21 +257,23 @@ def test_on_exception_success_random_jitter(monkeypatch):
 
     for i in range(2):
         details = backoffs[i]
-        assert details['wait'] >= 0.5 * 2 ** i
+        assert details["wait"] >= 0.5 * 2**i
 
 
 def test_on_exception_success_full_jitter(monkeypatch):
-    monkeypatch.setattr('time.sleep', lambda x: None)
+    monkeypatch.setattr("time.sleep", lambda x: None)
 
     backoffs, giveups, successes = [], [], []
 
-    @backoff.on_exception(backoff.expo,
-                          Exception,
-                          on_success=successes.append,
-                          on_backoff=backoffs.append,
-                          on_giveup=giveups.append,
-                          jitter=backoff.full_jitter,
-                          factor=0.5)
+    @backoff.on_exception(
+        backoff.expo,
+        Exception,
+        on_success=successes.append,
+        on_backoff=backoffs.append,
+        on_giveup=giveups.append,
+        jitter=backoff.full_jitter,
+        factor=0.5,
+    )
     @_save_target
     def succeeder(*args, **kwargs):
         # succeed after we've backed off twice
@@ -288,19 +289,21 @@ def test_on_exception_success_full_jitter(monkeypatch):
 
     for i in range(2):
         details = backoffs[i]
-        assert details['wait'] <= 0.5 * 2 ** i
+        assert details["wait"] <= 0.5 * 2**i
 
 
 def test_on_exception_success():
     backoffs, giveups, successes = [], [], []
 
-    @backoff.on_exception(backoff.constant,
-                          Exception,
-                          on_success=successes.append,
-                          on_backoff=backoffs.append,
-                          on_giveup=giveups.append,
-                          jitter=None,
-                          interval=0)
+    @backoff.on_exception(
+        backoff.constant,
+        Exception,
+        on_success=successes.append,
+        on_backoff=backoffs.append,
+        on_giveup=giveups.append,
+        jitter=None,
+        interval=0,
+    )
     @_save_target
     def succeeder(*args, **kwargs):
         # succeed after we've backed off twice
@@ -316,38 +319,44 @@ def test_on_exception_success():
 
     for i in range(2):
         details = backoffs[i]
-        elapsed = details.pop('elapsed')
-        exception = details.pop('exception')
+        elapsed = details.pop("elapsed")
+        exception = details.pop("exception")
         assert isinstance(elapsed, float)
         assert isinstance(exception, ValueError)
-        assert details == {'args': (1, 2, 3),
-                           'kwargs': {'foo': 1, 'bar': 2},
-                           'target': succeeder._target,
-                           'tries': i + 1,
-                           'wait': 0}
+        assert details == {
+            "args": (1, 2, 3),
+            "kwargs": {"foo": 1, "bar": 2},
+            "target": succeeder._target,
+            "tries": i + 1,
+            "wait": 0,
+        }
 
     details = successes[0]
-    elapsed = details.pop('elapsed')
+    elapsed = details.pop("elapsed")
     assert isinstance(elapsed, float)
-    assert details == {'args': (1, 2, 3),
-                       'kwargs': {'foo': 1, 'bar': 2},
-                       'target': succeeder._target,
-                       'tries': 3}
+    assert details == {
+        "args": (1, 2, 3),
+        "kwargs": {"foo": 1, "bar": 2},
+        "target": succeeder._target,
+        "tries": 3,
+    }
 
 
-@pytest.mark.parametrize('raise_on_giveup', [True, False])
+@pytest.mark.parametrize("raise_on_giveup", [True, False])
 def test_on_exception_giveup(raise_on_giveup):
     backoffs, giveups, successes = [], [], []
 
-    @backoff.on_exception(backoff.constant,
-                          ValueError,
-                          on_success=successes.append,
-                          on_backoff=backoffs.append,
-                          on_giveup=giveups.append,
-                          max_tries=3,
-                          jitter=None,
-                          raise_on_giveup=raise_on_giveup,
-                          interval=0)
+    @backoff.on_exception(
+        backoff.constant,
+        ValueError,
+        on_success=successes.append,
+        on_backoff=backoffs.append,
+        on_giveup=giveups.append,
+        max_tries=3,
+        jitter=None,
+        raise_on_giveup=raise_on_giveup,
+        interval=0,
+    )
     @_save_target
     def exceptor(*args, **kwargs):
         raise ValueError("catch me")
@@ -364,27 +373,27 @@ def test_on_exception_giveup(raise_on_giveup):
     assert len(giveups) == 1
 
     details = giveups[0]
-    elapsed = details.pop('elapsed')
-    exception = details.pop('exception')
+    elapsed = details.pop("elapsed")
+    exception = details.pop("exception")
     assert isinstance(elapsed, float)
     assert isinstance(exception, ValueError)
-    assert details == {'args': (1, 2, 3),
-                       'kwargs': {'foo': 1, 'bar': 2},
-                       'target': exceptor._target,
-                       'tries': 3}
+    assert details == {
+        "args": (1, 2, 3),
+        "kwargs": {"foo": 1, "bar": 2},
+        "target": exceptor._target,
+        "tries": 3,
+    }
 
 
 def test_on_exception_giveup_predicate(monkeypatch):
-    monkeypatch.setattr('time.sleep', lambda x: None)
+    monkeypatch.setattr("time.sleep", lambda x: None)
 
     def on_baz(e):
         return str(e) == "baz"
 
     vals = ["baz", "bar", "foo"]
 
-    @backoff.on_exception(backoff.constant,
-                          ValueError,
-                          giveup=on_baz)
+    @backoff.on_exception(backoff.constant, ValueError, giveup=on_baz)
     def foo_bar_baz():
         raise ValueError(vals.pop())
 
@@ -397,12 +406,14 @@ def test_on_exception_giveup_predicate(monkeypatch):
 def test_on_predicate_success():
     backoffs, giveups, successes = [], [], []
 
-    @backoff.on_predicate(backoff.constant,
-                          on_success=successes.append,
-                          on_backoff=backoffs.append,
-                          on_giveup=giveups.append,
-                          jitter=None,
-                          interval=0)
+    @backoff.on_predicate(
+        backoff.constant,
+        on_success=successes.append,
+        on_backoff=backoffs.append,
+        on_giveup=giveups.append,
+        jitter=None,
+        interval=0,
+    )
     @_save_target
     def success(*args, **kwargs):
         # succeed after we've backed off twice
@@ -418,35 +429,41 @@ def test_on_predicate_success():
     for i in range(2):
         details = backoffs[i]
 
-        elapsed = details.pop('elapsed')
+        elapsed = details.pop("elapsed")
         assert isinstance(elapsed, float)
-        assert details == {'args': (1, 2, 3),
-                           'kwargs': {'foo': 1, 'bar': 2},
-                           'target': success._target,
-                           'tries': i + 1,
-                           'value': False,
-                           'wait': 0}
+        assert details == {
+            "args": (1, 2, 3),
+            "kwargs": {"foo": 1, "bar": 2},
+            "target": success._target,
+            "tries": i + 1,
+            "value": False,
+            "wait": 0,
+        }
 
     details = successes[0]
-    elapsed = details.pop('elapsed')
+    elapsed = details.pop("elapsed")
     assert isinstance(elapsed, float)
-    assert details == {'args': (1, 2, 3),
-                       'kwargs': {'foo': 1, 'bar': 2},
-                       'target': success._target,
-                       'tries': 3,
-                       'value': True}
+    assert details == {
+        "args": (1, 2, 3),
+        "kwargs": {"foo": 1, "bar": 2},
+        "target": success._target,
+        "tries": 3,
+        "value": True,
+    }
 
 
 def test_on_predicate_giveup():
     backoffs, giveups, successes = [], [], []
 
-    @backoff.on_predicate(backoff.constant,
-                          on_success=successes.append,
-                          on_backoff=backoffs.append,
-                          on_giveup=giveups.append,
-                          max_tries=3,
-                          jitter=None,
-                          interval=0)
+    @backoff.on_predicate(
+        backoff.constant,
+        on_success=successes.append,
+        on_backoff=backoffs.append,
+        on_giveup=giveups.append,
+        max_tries=3,
+        jitter=None,
+        interval=0,
+    )
     @_save_target
     def emptiness(*args, **kwargs):
         pass
@@ -459,13 +476,15 @@ def test_on_predicate_giveup():
     assert len(giveups) == 1
 
     details = giveups[0]
-    elapsed = details.pop('elapsed')
+    elapsed = details.pop("elapsed")
     assert isinstance(elapsed, float)
-    assert details == {'args': (1, 2, 3),
-                       'kwargs': {'foo': 1, 'bar': 2},
-                       'target': emptiness._target,
-                       'tries': 3,
-                       'value': None}
+    assert details == {
+        "args": (1, 2, 3),
+        "kwargs": {"foo": 1, "bar": 2},
+        "target": emptiness._target,
+        "tries": 3,
+        "value": None,
+    }
 
 
 def test_on_predicate_iterable_handlers():
@@ -477,13 +496,15 @@ def test_on_predicate_iterable_handlers():
 
     loggers = [Logger() for _ in range(3)]
 
-    @backoff.on_predicate(backoff.constant,
-                          on_backoff=(l.backoffs.append for l in loggers),  # noqa: E741
-                          on_giveup=(l.giveups.append for l in loggers),  # noqa: E741
-                          on_success=(l.successes.append for l in loggers),  # noqa: E741
-                          max_tries=3,
-                          jitter=None,
-                          interval=0)
+    @backoff.on_predicate(
+        backoff.constant,
+        on_backoff=(l.backoffs.append for l in loggers),  # noqa: E741
+        on_giveup=(l.giveups.append for l in loggers),  # noqa: E741
+        on_success=(l.successes.append for l in loggers),  # noqa: E741
+        max_tries=3,
+        jitter=None,
+        interval=0,
+    )
     @_save_target
     def emptiness(*args, **kwargs):
         pass
@@ -491,36 +512,39 @@ def test_on_predicate_iterable_handlers():
     emptiness(1, 2, 3, foo=1, bar=2)
 
     for logger in loggers:
-
         assert len(logger.successes) == 0
         assert len(logger.backoffs) == 2
         assert len(logger.giveups) == 1
 
         details = dict(logger.giveups[0])
-        elapsed = details.pop('elapsed')
+        elapsed = details.pop("elapsed")
         assert isinstance(elapsed, float)
-        assert details == {'args': (1, 2, 3),
-                           'kwargs': {'foo': 1, 'bar': 2},
-                           'target': emptiness._target,
-                           'tries': 3,
-                           'value': None}
+        assert details == {
+            "args": (1, 2, 3),
+            "kwargs": {"foo": 1, "bar": 2},
+            "target": emptiness._target,
+            "tries": 3,
+            "value": None,
+        }
 
 
 # To maintain backward compatibility,
 # on_predicate should support 0-argument jitter function.
 def test_on_exception_success_0_arg_jitter(monkeypatch):
-    monkeypatch.setattr('time.sleep', lambda x: None)
-    monkeypatch.setattr('random.random', lambda: 0)
+    monkeypatch.setattr("time.sleep", lambda x: None)
+    monkeypatch.setattr("random.random", lambda: 0)
 
     backoffs, giveups, successes = [], [], []
 
-    @backoff.on_exception(backoff.constant,
-                          Exception,
-                          on_success=successes.append,
-                          on_backoff=backoffs.append,
-                          on_giveup=giveups.append,
-                          jitter=random.random,
-                          interval=0)
+    @backoff.on_exception(
+        backoff.constant,
+        Exception,
+        on_success=successes.append,
+        on_backoff=backoffs.append,
+        on_giveup=giveups.append,
+        jitter=random.random,
+        interval=0,
+    )
     @_save_target
     def succeeder(*args, **kwargs):
         # succeed after we've backed off twice
@@ -537,39 +561,45 @@ def test_on_exception_success_0_arg_jitter(monkeypatch):
 
     for i in range(2):
         details = backoffs[i]
-        elapsed = details.pop('elapsed')
-        exception = details.pop('exception')
+        elapsed = details.pop("elapsed")
+        exception = details.pop("exception")
         assert isinstance(elapsed, float)
         assert isinstance(exception, ValueError)
-        assert details == {'args': (1, 2, 3),
-                           'kwargs': {'foo': 1, 'bar': 2},
-                           'target': succeeder._target,
-                           'tries': i + 1,
-                           'wait': 0}
+        assert details == {
+            "args": (1, 2, 3),
+            "kwargs": {"foo": 1, "bar": 2},
+            "target": succeeder._target,
+            "tries": i + 1,
+            "wait": 0,
+        }
 
     details = successes[0]
-    elapsed = details.pop('elapsed')
+    elapsed = details.pop("elapsed")
     assert isinstance(elapsed, float)
-    assert details == {'args': (1, 2, 3),
-                       'kwargs': {'foo': 1, 'bar': 2},
-                       'target': succeeder._target,
-                       'tries': 3}
+    assert details == {
+        "args": (1, 2, 3),
+        "kwargs": {"foo": 1, "bar": 2},
+        "target": succeeder._target,
+        "tries": 3,
+    }
 
 
 # To maintain backward compatibility,
 # on_predicate should support 0-argument jitter function.
 def test_on_predicate_success_0_arg_jitter(monkeypatch):
-    monkeypatch.setattr('time.sleep', lambda x: None)
-    monkeypatch.setattr('random.random', lambda: 0)
+    monkeypatch.setattr("time.sleep", lambda x: None)
+    monkeypatch.setattr("random.random", lambda: 0)
 
     backoffs, giveups, successes = [], [], []
 
-    @backoff.on_predicate(backoff.constant,
-                          on_success=successes.append,
-                          on_backoff=backoffs.append,
-                          on_giveup=giveups.append,
-                          jitter=random.random,
-                          interval=0)
+    @backoff.on_predicate(
+        backoff.constant,
+        on_success=successes.append,
+        on_backoff=backoffs.append,
+        on_giveup=giveups.append,
+        jitter=random.random,
+        interval=0,
+    )
     @_save_target
     def success(*args, **kwargs):
         # succeed after we've backed off twice
@@ -585,27 +615,31 @@ def test_on_predicate_success_0_arg_jitter(monkeypatch):
 
     for i in range(2):
         details = backoffs[i]
-        elapsed = details.pop('elapsed')
+        elapsed = details.pop("elapsed")
         assert isinstance(elapsed, float)
-        assert details == {'args': (1, 2, 3),
-                           'kwargs': {'foo': 1, 'bar': 2},
-                           'target': success._target,
-                           'tries': i + 1,
-                           'value': False,
-                           'wait': 0}
+        assert details == {
+            "args": (1, 2, 3),
+            "kwargs": {"foo": 1, "bar": 2},
+            "target": success._target,
+            "tries": i + 1,
+            "value": False,
+            "wait": 0,
+        }
 
     details = successes[0]
-    elapsed = details.pop('elapsed')
+    elapsed = details.pop("elapsed")
     assert isinstance(elapsed, float)
-    assert details == {'args': (1, 2, 3),
-                       'kwargs': {'foo': 1, 'bar': 2},
-                       'target': success._target,
-                       'tries': 3,
-                       'value': True}
+    assert details == {
+        "args": (1, 2, 3),
+        "kwargs": {"foo": 1, "bar": 2},
+        "target": success._target,
+        "tries": 3,
+        "value": True,
+    }
 
 
 def test_on_exception_callable_max_tries(monkeypatch):
-    monkeypatch.setattr('time.sleep', lambda x: None)
+    monkeypatch.setattr("time.sleep", lambda x: None)
 
     log = []
 
@@ -621,7 +655,7 @@ def test_on_exception_callable_max_tries(monkeypatch):
 
 
 def test_on_exception_callable_max_tries_reads_every_time(monkeypatch):
-    monkeypatch.setattr('time.sleep', lambda x: None)
+    monkeypatch.setattr("time.sleep", lambda x: None)
 
     lookups = []
 
@@ -629,9 +663,7 @@ def test_on_exception_callable_max_tries_reads_every_time(monkeypatch):
         lookups.append(True)
         return 3
 
-    @backoff.on_exception(backoff.constant,
-                          ValueError,
-                          max_tries=lookup_max_tries)
+    @backoff.on_exception(backoff.constant, ValueError, max_tries=lookup_max_tries)
     def exceptor():
         raise ValueError()
 
@@ -645,7 +677,6 @@ def test_on_exception_callable_max_tries_reads_every_time(monkeypatch):
 
 
 def test_on_exception_callable_gen_kwargs():
-
     def lookup_foo():
         return "foo"
 
@@ -656,11 +687,7 @@ def test_on_exception_callable_gen_kwargs():
         while True:
             yield 0
 
-    @backoff.on_exception(wait_gen,
-                          ValueError,
-                          max_tries=2,
-                          foo=lookup_foo,
-                          bar="bar")
+    @backoff.on_exception(wait_gen, ValueError, max_tries=2, foo=lookup_foo, bar="bar")
     def exceptor():
         raise ValueError("aah")
 
@@ -669,38 +696,39 @@ def test_on_exception_callable_gen_kwargs():
 
 
 def test_on_predicate_in_thread(monkeypatch):
-    monkeypatch.setattr('time.sleep', lambda x: None)
+    monkeypatch.setattr("time.sleep", lambda x: None)
 
     result = []
 
     def check():
         try:
+
             @backoff.on_predicate(backoff.expo)
             def return_true(log, n):
-                val = (len(log) == n - 1)
+                val = len(log) == n - 1
                 log.append(val)
                 return val
 
             log = []
             ret = return_true(log, 3)
             assert ret is True
-            assert 3 == len(log)
+            assert len(log) == 3
 
         except Exception as ex:
             result.append(ex)
         else:
-            result.append('success')
+            result.append("success")
 
     t = threading.Thread(target=check)
     t.start()
     t.join()
 
     assert len(result) == 1
-    assert result[0] == 'success'
+    assert result[0] == "success"
 
 
 def test_on_predicate_constant_iterable(monkeypatch):
-    monkeypatch.setattr('time.sleep', lambda x: None)
+    monkeypatch.setattr("time.sleep", lambda x: None)
 
     waits = [1, 2, 3, 6, 9]
     backoffs = []
@@ -722,19 +750,20 @@ def test_on_predicate_constant_iterable(monkeypatch):
 
     assert len(backoffs) == len(waits)
     for i, wait in enumerate(waits):
-        assert backoffs[i]['wait'] == wait
+        assert backoffs[i]["wait"] == wait
 
     assert len(giveups) == 1
     assert len(successes) == 0
 
 
 def test_on_exception_in_thread(monkeypatch):
-    monkeypatch.setattr('time.sleep', lambda x: None)
+    monkeypatch.setattr("time.sleep", lambda x: None)
 
     result = []
 
     def check():
         try:
+
             @backoff.on_exception(backoff.expo, KeyError)
             def keyerror_then_true(log, n):
                 if len(log) == n:
@@ -745,25 +774,25 @@ def test_on_exception_in_thread(monkeypatch):
 
             log = []
             assert keyerror_then_true(log, 3) is True
-            assert 3 == len(log)
+            assert len(log) == 3
 
         except Exception as ex:
             result.append(ex)
         else:
-            result.append('success')
+            result.append("success")
 
     t = threading.Thread(target=check)
     t.start()
     t.join()
 
     assert len(result) == 1
-    assert result[0] == 'success'
+    assert result[0] == "success"
 
 
 def test_on_exception_logger_default(monkeypatch, caplog):
-    monkeypatch.setattr('time.sleep', lambda x: None)
+    monkeypatch.setattr("time.sleep", lambda x: None)
 
-    logger = logging.getLogger('backoff')
+    logger = logging.getLogger("backoff")
     handler = logging.StreamHandler(sys.stdout)
     logger.addHandler(handler)
 
@@ -771,19 +800,18 @@ def test_on_exception_logger_default(monkeypatch, caplog):
     def key_error():
         raise KeyError()
 
-    with caplog.at_level(logging.INFO):
-        with pytest.raises(KeyError):
-            key_error()
+    with caplog.at_level(logging.INFO), pytest.raises(KeyError):
+        key_error()
 
     assert len(caplog.records) == 3  # 2 backoffs and 1 giveup
     for record in caplog.records:
-        assert record.name == 'backoff'
+        assert record.name == "backoff"
 
 
 def test_on_exception_logger_none(monkeypatch, caplog):
-    monkeypatch.setattr('time.sleep', lambda x: None)
+    monkeypatch.setattr("time.sleep", lambda x: None)
 
-    logger = logging.getLogger('backoff')
+    logger = logging.getLogger("backoff")
     handler = logging.StreamHandler(sys.stdout)
     logger.addHandler(handler)
 
@@ -791,17 +819,16 @@ def test_on_exception_logger_none(monkeypatch, caplog):
     def key_error():
         raise KeyError()
 
-    with caplog.at_level(logging.INFO):
-        with pytest.raises(KeyError):
-            key_error()
+    with caplog.at_level(logging.INFO), pytest.raises(KeyError):
+        key_error()
 
     assert not caplog.records
 
 
 def test_on_exception_logger_user(monkeypatch, caplog):
-    monkeypatch.setattr('time.sleep', lambda x: None)
+    monkeypatch.setattr("time.sleep", lambda x: None)
 
-    logger = logging.getLogger('my-logger')
+    logger = logging.getLogger("my-logger")
     handler = logging.StreamHandler(sys.stdout)
     logger.addHandler(handler)
 
@@ -809,38 +836,37 @@ def test_on_exception_logger_user(monkeypatch, caplog):
     def key_error():
         raise KeyError()
 
-    with caplog.at_level(logging.INFO):
-        with pytest.raises(KeyError):
-            key_error()
+    with caplog.at_level(logging.INFO), pytest.raises(KeyError):
+        key_error()
 
     assert len(caplog.records) == 3  # 2 backoffs and 1 giveup
     for record in caplog.records:
-        assert record.name == 'my-logger'
+        assert record.name == "my-logger"
 
 
 def test_on_exception_logger_user_str(monkeypatch, caplog):
-    monkeypatch.setattr('time.sleep', lambda x: None)
+    monkeypatch.setattr("time.sleep", lambda x: None)
 
-    logger = logging.getLogger('my-logger')
+    logger = logging.getLogger("my-logger")
     handler = logging.StreamHandler(sys.stdout)
     logger.addHandler(handler)
 
-    @backoff.on_exception(backoff.expo, KeyError, max_tries=3,
-                          logger='my-logger')
+    @backoff.on_exception(backoff.expo, KeyError, max_tries=3, logger="my-logger")
     def key_error():
         raise KeyError()
 
-    with caplog.at_level(logging.INFO):
-        with pytest.raises(KeyError):
-            key_error()
+    with caplog.at_level(logging.INFO), pytest.raises(KeyError):
+        key_error()
 
     assert len(caplog.records) == 3  # 2 backoffs and 1 giveup
     for record in caplog.records:
-        assert record.name == 'my-logger'
+        assert record.name == "my-logger"
 
 
 def _on_exception_factory(
-    backoff_log_level, giveup_log_level, max_tries,
+    backoff_log_level,
+    giveup_log_level,
+    max_tries,
 ):
     @backoff.on_exception(
         backoff.expo,
@@ -860,7 +886,9 @@ def _on_exception_factory(
 
 
 def _on_predicate_factory(
-    backoff_log_level, giveup_log_level, max_tries,
+    backoff_log_level,
+    giveup_log_level,
+    max_tries,
 ):
     @backoff.on_predicate(
         backoff.expo,
@@ -892,16 +920,19 @@ def _on_predicate_factory(
     ),
 )
 def test_event_log_levels(
-    caplog, func_factory, backoff_log_level, giveup_log_level,
+    caplog,
+    func_factory,
+    backoff_log_level,
+    giveup_log_level,
 ):
     max_tries = 3
     func = func_factory(backoff_log_level, giveup_log_level, max_tries)
 
-    with unittest.mock.patch('time.sleep', return_value=None):
-        with caplog.at_level(
-            min(backoff_log_level, giveup_log_level), logger="backoff",
-        ):
-            func()
+    with unittest.mock.patch("time.sleep", return_value=None), caplog.at_level(
+        min(backoff_log_level, giveup_log_level),
+        logger="backoff",
+    ):
+        func()
 
     backoff_re = re.compile("backing off", re.IGNORECASE)
     giveup_re = re.compile("giving up", re.IGNORECASE)
